<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class UserNotification extends Model {

    public $table = 'user_notifications';
    public $primaryKey = 'id';

    protected $fillable = ['cta_label'];
}
